#!/usr/env python3

import numpy as np
import techdraw as svg

def draw_state(parent, pos, angle):
    svg.Dot(parent, pos)
    svg.Line(parent, pos, pos + svg.pol2cart(10, angle), svg.THIN_STROKE)

def test_path_creator_line():
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), np.radians(30))
    draw_state(img.content, p.pos(), p.alpha)
    p.line_to((5, 25), (0, 15), (-10, 25))
    draw_state(img.content, p.pos(), p.alpha)
    p.line(10)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-line.svg')

def test_path_creator_curve():
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), np.radians(30))
    draw_state(img.content, p.pos(), p.alpha)
    p.curve_to((10, 25), svg.radians(90))
    draw_state(img.content, p.pos(), p.alpha)
    p.curve_to((0, 30), svg.radians(180))
    draw_state(img.content, p.pos(), p.alpha)
    p.curve_to((0, 15), svg.radians(-135))
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-curve.svg')

def test_path_creator_arc_to_line():
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q, beta = (0, -10), svg.radians(60)
    draw_state(img.content, Q, beta)
    p.arc_to_line(Q, beta)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-line-1.svg')

    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q, beta = (0, 10), svg.radians(-60)
    draw_state(img.content, Q, beta)
    p.arc_to_line(Q, beta)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-line-2.svg')

    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q, beta = (-10, 0), svg.radians(-60)
    draw_state(img.content, Q, beta)
    p.arc_to_line(Q, beta)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-line-3.svg')

    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q, beta = (-10, 0), svg.radians(60)
    draw_state(img.content, Q, beta)
    p.arc_to_line(Q, beta)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-line-4.svg')

    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q, beta = (0, 0), svg.radians(60)
    draw_state(img.content, Q, beta)
    p.arc_to_line(Q, beta)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-line-5.svg')

    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q, beta = (10, 10), svg.radians(0)
    draw_state(img.content, Q, beta)
    p.arc_to_line(Q, beta)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-line-6.svg')

    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q, beta = (10, 10), svg.radians(180)
    draw_state(img.content, Q, beta)
    p.arc_to_line(Q, beta)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-line-7.svg')

def test_path_creator_arc_to_point():
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q= (0, -10)
    p.arc_to_point(Q, 20)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-point-1.svg')

    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    Q= (0, -10)
    p.arc_to_point(Q, -20)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-to-point-2.svg')

def test_path_creator_arc():
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    p.arc(10, 20)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-1.svg')
    
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    p.arc(10, -20)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-2.svg')
    
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    p.arc(30, 10)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-3.svg')
    
    img = svg.Image(size=(100, 100), center=(50, 50))
    p = svg.PathCreator((0, 0), 0)
    draw_state(img.content, p.pos(), p.alpha)
    p.arc(40, 10)
    draw_state(img.content, p.pos(), p.alpha)
    svg.Path(img.content, p.path, fill='none')
    img.write('test-path-creator-arc-4.svg')
    

if __name__ == "__main__":
    test_path_creator_arc_to_line()
    test_path_creator_arc_to_point()
    test_path_creator_arc()
    test_path_creator_curve()
    test_path_creator_line()
